<?php
/**
 * Plugin Name: Woo Countdown Plugin (EasyToolsWP)
 * Description: [etwp_cd_countdown] Adds a countdown to WooCommerce product pages and a shortcode for manual insertion.
 * Version: 2.0.1
 * Author: EasyToolsWP.com
 */

if (!defined('ABSPATH')) {
    exit;
}

// Add settings page in the admin menu
function etwp_cd_add_settings_page() {
    add_options_page(
        'Countdown Settings', 
        'Countdown Settings', 
        'manage_options', 
        'etwp_cd_countdown_settings', 
        'etwp_cd_render_settings_page'
    );
}
add_action('admin_menu', 'etwp_cd_add_settings_page');

// Render settings page
function etwp_cd_render_settings_page() {
    ?>
    <div class="wrap">
        <h1>Countdown Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('etwp_cd_settings_group');
            do_settings_sections('etwp_cd_countdown_settings');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// Register settings
function etwp_cd_register_settings() {
    register_setting('etwp_cd_settings_group', 'etwp_cd_delivery_times', 'etwp_cd_sanitize_delivery_times');
    register_setting('etwp_cd_settings_group', 'etwp_cd_text_prefix');
    register_setting('etwp_cd_settings_group', 'etwp_cd_text_suffix');
    register_setting('etwp_cd_settings_group', 'etwp_cd_day_translations'); // NEW: For day translations
    register_setting('etwp_cd_settings_group', 'etwp_cd_hide_day_time');
    register_setting('etwp_cd_settings_group', 'etwp_cd_hours_translation');
    register_setting('etwp_cd_settings_group', 'etwp_cd_minutes_translation');
    register_setting('etwp_cd_settings_group', 'etwp_cd_today_translation');

    add_settings_section('etwp_cd_main_section', 'Shipping Times', null, 'etwp_cd_countdown_settings');

    // Add fields for each day (two time slots per day)
    $days = ['monday' => 'Monday', 'tuesday' => 'Tuesday', 'wednesday' => 'Wednesday', 'thursday' => 'Thursday', 'friday' => 'Friday', 'saturday' => 'Saturday', 'sunday' => 'Sunday'];
    foreach ($days as $day_key => $day_label) {
        add_settings_field(
            'etwp_cd_' . $day_key, 
            $day_label, 
            'etwp_cd_render_day_field', 
            'etwp_cd_countdown_settings', 
            'etwp_cd_main_section', 
            ['day_key' => $day_key, 'day_label' => $day_label]
        );
    }

    add_settings_section('etwp_cd_text_section', 'Texts', null, 'etwp_cd_countdown_settings');
    add_settings_field('etwp_cd_text_prefix', 'Prefix', 'etwp_cd_render_text_input', 'etwp_cd_countdown_settings', 'etwp_cd_text_section', ['id' => 'etwp_cd_text_prefix']);
    add_settings_field('etwp_cd_text_suffix', 'Suffix', 'etwp_cd_render_text_input', 'etwp_cd_countdown_settings', 'etwp_cd_text_section', ['id' => 'etwp_cd_text_suffix']);
    add_settings_field('etwp_cd_hours_translation', 'Translation for "hours"', 'etwp_cd_render_text_input', 'etwp_cd_countdown_settings', 'etwp_cd_text_section', ['id' => 'etwp_cd_hours_translation']);
    add_settings_field('etwp_cd_minutes_translation', 'Translation for "minutes"', 'etwp_cd_render_text_input', 'etwp_cd_countdown_settings', 'etwp_cd_text_section', ['id' => 'etwp_cd_minutes_translation']);
    add_settings_field('etwp_cd_today_translation', 'Translation for "Today"', 'etwp_cd_render_text_input', 'etwp_cd_countdown_settings', 'etwp_cd_text_section', ['id' => 'etwp_cd_today_translation']);
    
    // Add fields for translating day names
    foreach ($days as $day_key => $day_label) {
        add_settings_field(
            'etwp_cd_translation_' . $day_key,
            'Translation for ' . $day_label,
            'etwp_cd_render_day_translation_input',
            'etwp_cd_countdown_settings',
            'etwp_cd_text_section',
            ['day_key' => $day_key, 'day_label' => $day_label]
        );
    }

    // Checkbox for showing only time (Hide day and time)
    add_settings_field('etwp_cd_hide_day_time', 'Hide day and time (Show only hours & minutes)', 'etwp_cd_render_hide_day_time_checkbox', 'etwp_cd_countdown_settings', 'etwp_cd_text_section');
}
add_action('admin_init', 'etwp_cd_register_settings');

// Sanitize and validate delivery times
function etwp_cd_sanitize_delivery_times($input) {
    $sanitized = [];
    
    $days = ['monday', 'tuesday', 'wednesday', 'thursday', 'friday', 'saturday', 'sunday'];
    foreach ($days as $day_key) {
        if (isset($input[$day_key]['enabled'])) {
            $sanitized[$day_key]['enabled'] = sanitize_text_field($input[$day_key]['enabled']);
            $sanitized[$day_key]['time1'] = sanitize_text_field($input[$day_key]['time1']);
            $sanitized[$day_key]['time2'] = sanitize_text_field($input[$day_key]['time2']);
        }
    }
    
    return $sanitized;
}

// Render checkbox and time input for each day (support for two time slots per day)
function etwp_cd_render_day_field($args) {
    $day_key = $args['day_key'];
    $options = get_option('etwp_cd_delivery_times');
    $checked = isset($options[$day_key]['enabled']) ? 'checked' : '';
    $time1 = isset($options[$day_key]['time1']) ? $options[$day_key]['time1'] : '10:00';
    $time2 = isset($options[$day_key]['time2']) ? $options[$day_key]['time2'] : '17:00';
    ?>
    <label>
        <input type="checkbox" name="etwp_cd_delivery_times[<?php echo $day_key; ?>][enabled]" value="1" <?php echo $checked; ?> />
        Active
    </label>
    <input type="time" name="etwp_cd_delivery_times[<?php echo $day_key; ?>][time1]" value="<?php echo esc_attr($time1); ?>" placeholder="First time" />
    <input type="time" name="etwp_cd_delivery_times[<?php echo $day_key; ?>][time2]" value="<?php echo esc_attr($time2); ?>" placeholder="Second time (optional)" />
    <?php
}

// Render translation input for each day
function etwp_cd_render_day_translation_input($args) {
    $day_key = $args['day_key'];
    $options = get_option('etwp_cd_day_translations');
    $value = isset($options[$day_key]) ? $options[$day_key] : ucfirst($day_key);
    ?>
    <input type="text" name="etwp_cd_day_translations[<?php echo $day_key; ?>]" value="<?php echo esc_attr($value); ?>" placeholder="Translation for <?php echo ucfirst($day_key); ?>" />
    <?php
}

// Render text input fields
function etwp_cd_render_text_input($args) {
    $id = $args['id'];
    $value = get_option($id, '');
    ?>
    <input type="text" name="<?php echo $id; ?>" value="<?php echo esc_attr($value); ?>" />
    <?php
}

// Render hide day and time checkbox
function etwp_cd_render_hide_day_time_checkbox() {
    $checked = get_option('etwp_cd_hide_day_time', false) ? 'checked' : '';
    ?>
    <input type="checkbox" name="etwp_cd_hide_day_time" value="1" <?php echo $checked; ?> />
    <?php
}

// Shortcode for countdown
function etwp_cd_countdown_shortcode() {
    return etwp_cd_render_countdown();
}
add_shortcode('etwp_cd_countdown', 'etwp_cd_countdown_shortcode');

// Add countdown under price on WooCommerce product pages
function etwp_cd_add_countdown_to_product_page() {
    if (class_exists('WooCommerce')) {
        echo etwp_cd_render_countdown();
    }
}
add_action('woocommerce_single_product_summary', 'etwp_cd_add_countdown_to_product_page', 25);

// Render countdown function
function etwp_cd_render_countdown() {
    $options = get_option('etwp_cd_delivery_times');
    $prefix = get_option('etwp_cd_text_prefix', 'Order by');
    $suffix = get_option('etwp_cd_text_suffix', '');
    $hours_translation = get_option('etwp_cd_hours_translation', 'hours');
    $minutes_translation = get_option('etwp_cd_minutes_translation', 'minutes');
    $today_translation = get_option('etwp_cd_today_translation', 'Today');
    $translations = get_option('etwp_cd_day_translations', []); // Get translations

    $next_deadline_data = etwp_cd_get_next_deadline($options);

    if ($next_deadline_data) {
        $remaining_seconds = $next_deadline_data['timestamp'] - time();
        $hours = floor($remaining_seconds / 3600);
        $minutes = floor(($remaining_seconds % 3600) / 60);

        // Use translated day name or default if translation is not set
        $day_name = ucfirst($next_deadline_data['day']);
        if (isset($translations[$next_deadline_data['day']])) {
            $day_name = $translations[$next_deadline_data['day']];
        }

// Replace with 'Today' if the deadline is today
if (date('Y-m-d') == date('Y-m-d', $next_deadline_data['timestamp'])) {
    $day_name = $today_translation;
}

// Output with a CSS class
$output = '<div class="etwp-countdown">' . $prefix . ' ' . $day_name . ', ' . $next_deadline_data['time'] . ' (' . $hours . ' ' . $hours_translation . ' & ' . $minutes . ' ' . $minutes_translation . ')' . ' ' . $suffix . '</div>';

if (get_option('etwp_cd_hide_day_time', false)) {
    $output = '<div class="etwp-countdown">' . $prefix . ' ' . $hours . ' ' . $hours_translation . ' & ' . $minutes . ' ' . $minutes_translation . ' ' . $suffix . '</div>';
}

return $output;

    }

    return '';
}

// Helper function to get next deadline
function etwp_cd_get_next_deadline($options) {
    $days_of_week = ['monday' => 1, 'tuesday' => 2, 'wednesday' => 3, 'thursday' => 4, 'friday' => 5, 'saturday' => 6, 'sunday' => 0];
    $next_deadline = null;
    $current_time = time();

    foreach ($days_of_week as $day_key => $day_num) {
        if (!empty($options[$day_key]['enabled'])) {
            // Time 1
            if (!empty($options[$day_key]['time1'])) {
                $time1 = $options[$day_key]['time1'];
                $next_time1 = strtotime("next $day_key $time1");

                // Check if today is the correct day and time has not passed yet
                if (date('N') == $day_num && strtotime($time1) > $current_time) {
                    $next_time1 = strtotime("today $time1");
                }

                if ($next_time1 > $current_time && (!$next_deadline || $next_time1 < $next_deadline['timestamp'])) {
                    $next_deadline = [
                        'day' => $day_key,
                        'time' => date('H:i', strtotime($time1)),
                        'timestamp' => $next_time1,
                        'deadline' => date('Y-m-d H:i:s', $next_time1)
                    ];
                }
            }

            // Time 2 (optional)
            if (!empty($options[$day_key]['time2'])) {
                $time2 = $options[$day_key]['time2'];
                $next_time2 = strtotime("next $day_key $time2");

                // Check if today is the correct day and time has not passed yet
                if (date('N') == $day_num && strtotime($time2) > $current_time) {
                    $next_time2 = strtotime("today $time2");
                }

                if ($next_time2 > $current_time && (!$next_deadline || $next_time2 < $next_deadline['timestamp'])) {
                    $next_deadline = [
                        'day' => $day_key,
                        'time' => date('H:i', strtotime($time2)),
                        'timestamp' => $next_time2,
                        'deadline' => date('Y-m-d H:i:s', $next_time2)
                    ];
                }
            }
        }
    }

    return $next_deadline;
}
